#
# Copyright (c) 2008-2017 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

# import standard library

# import interfaces
from onf_website.features.header.interfaces import IDefaultHeaderRendererSettings
from onf_website.skin.public.layer import IONFBaseLayer
from pyams_content.features.header.interfaces import IHeaderTarget, IHeaderSettings
from pyams_content.root.interfaces import ISiteRoot

# import packages
from pyams_template.template import template_config
from pyams_utils.traversing import get_parent
from pyams_viewlet.viewlet import contentprovider_config, ViewContentProvider
from pyramid.decorator import reify
from zope.interface import Interface


@contentprovider_config(name='pyams.logo',layer=IONFBaseLayer, view=Interface)
@template_config(template='templates/logo.pt', layer=IONFBaseLayer)
class Logo(ViewContentProvider):
    """Logo content provider"""

    @reify
    def settings(self):
        target = get_parent(self.context, IHeaderTarget)
        settings = IHeaderSettings(target)
        while settings.inherit:
            settings = IHeaderSettings(settings.parent)
        return IDefaultHeaderRendererSettings(settings.settings, None)


@contentprovider_config(name='pyams.logo', context=ISiteRoot, layer=IONFBaseLayer, view=Interface)
@template_config(template='templates/siteroot-logo.pt', layer=IONFBaseLayer)
class SiteRootLogo(Logo):
    """Site root logo content provider"""
